@@ -9,16 +9,16 @@ __author__ = "Jonas Van Der Donckt, Jeroen Van Der Donckt, Emiel Deprost"
 from .. import __pdoc__
 from .feature import FeatureDescriptor, MultipleFeatureDescriptors
 from .feature_collection import FeatureCollection
-from .function_wrapper import NumpyFuncWrapper
+from .function_wrapper import FuncWrapper
 from .logger import get_feature_logs, get_function_stats, get_series_names_stats
 
-__pdoc__["NumpyFuncWrapper.__call__"] = True
+__pdoc__["FuncWrapper.__call__"] = True
 
 __all__ = [
     "FeatureDescriptor",
     "MultipleFeatureDescriptors",
     "FeatureCollection",
-    "NumpyFuncWrapper",
+    "FuncWrapper",
     "get_feature_logs",
     "get_function_stats",
     "get_series_names_stats",
